@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Login Screen
 #
-# $Id: lonlogin.pm,v 1.93 2007/04/17 15:44:58 www Exp $
+# $Id: lonlogin.pm,v 1.94 2007/08/30 22:07:45 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -120,12 +120,10 @@ ENDFAILED
     }
 
     my $fullgraph=($env{'form.interface'} ne 'textual');
-    my $port_to_use=$r->dir_config('lonhttpdPort');
-    if (!defined($port_to_use)) {
-	$port_to_use='8080';
-    }
-    my $iconpath= 'http://'.$ENV{'HTTP_HOST'}.':'.$port_to_use.
-                  $r->dir_config('lonIconsURL');
+
+    my $iconpath= 
+	&Apache::loncommon::lonhttpdurl($r->dir_config('lonIconsURL'));
+
     my $domain = &Apache::lonnet::default_login_domain();
     if (($env{'form.domain'}) && 
 	(&Apache::lonnet::domain($env{'form.domain'},'description'))) {
