@@ -1,5 +1,5 @@
 #
-# $Id: batchcreatecourse.pm,v 1.22 2007/07/02 03:36:47 raeburn Exp $
+# $Id: batchcreatecourse.pm,v 1.23 2007/08/23 21:54:37 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -497,8 +497,8 @@ sub build_course {
             $$logmsg .= &mt('Invalid home server for course').': '.$$details{$num}{'coursehome'};
             return;
         }
-
-        $$logmsg .= &Apache::loncommon::construct_course($courseargs,$logmsg,\$courseid,\$crsudom,\$crsunum,$udom,$uname,$context);
+        my ($success, $msg) = &Apache::loncommon::construct_course($courseargs,$logmsg,\$courseid,\$crsudom,\$crsunum,$udom,$uname,$context);
+	$$logmsg .= $msg;
     } else {
         return;
     }
