@@ -2,7 +2,7 @@
 # The LearningOnline Network with CAPA
 # image click response style
 #
-# $Id: imageresponse.pm,v 1.82 2007/04/18 01:06:22 albertel Exp $
+# $Id: imageresponse.pm,v 1.83 2007/06/19 20:23:56 banghart Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -505,6 +505,7 @@ sub end_text {
 sub start_image {
     my ($target,$token,$tagstack,$parstack,$parser,$safeeval,$style)=@_;
     my $result='';
+    my $only = join(',',&Apache::loncommon::filecategorytypes('Pictures'));
     if ($target eq 'web' || $target eq 'tex' || $target eq 'analyze'
 	|| $target eq 'answer') { 
 	&Apache::lonxml::startredirection; 
@@ -515,7 +516,7 @@ sub start_image {
 
 	$result=&Apache::edit::tag_start($target,$token,'Clickable Image').
 	    &Apache::edit::editline($token->[1],$bgimg,'Image Source File',40);
-	$result.=&Apache::edit::browse(undef,'textnode').' ';
+	$result.=&Apache::edit::browse(undef,'textnode',undef,$only).' ';
 	$result.=&Apache::edit::search(undef,'textnode').
 	    &Apache::edit::end_row();
     } elsif ($target eq "modified") {
