@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # input  definitons
 #
-# $Id: inputtags.pm,v 1.227 2007/07/10 20:51:48 albertel Exp $
+# $Id: inputtags.pm,v 1.229 2007/08/14 19:32:42 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -31,7 +31,6 @@ use strict;
 use Apache::loncommon;
 use Apache::lonlocal;
 use Apache::lonnet;
-use lib '/home/httpd/lib/perl/';
 use LONCAPA;
  
 
@@ -116,8 +115,7 @@ sub check_for_duplicate_ids {
 
 sub start_input {
     my ($parstack,$safeeval)=@_;
-    my $id = &Apache::lonxml::get_param('id',$parstack,$safeeval);
-    if ($id eq '') { $id = $Apache::lonxml::curdepth; }
+    my $id = &Apache::lonxml::get_id($parstack,$safeeval);
     push (@Apache::inputtags::input,$id);
     push (@Apache::inputtags::inputlist,$id);
     return $id;
@@ -1225,17 +1223,16 @@ sub previous_tries {
 	&mt('Submitted Answer').'</th>';
     $output ='<table class="LC_prior_tries">'.$headers.$output.'</table>';
     #return $output;
-    $output=~s/\\/\\\\/g;
-    $output=~s/\'/\\\'/g;
-    $output=~s/\s+/ /g;
+    $output = &Apache::loncommon::js_ready($output); 
     $output.='<br /><form action=""><center><input type="button" name="close" value="'.&mt('Close Window').'" onClick="window.close()" /></center></form>';
 
     my $windowopen=&Apache::lonhtmlcommon::javascript_docopen();
     my $start_page =
 	&Apache::loncommon::start_page('Previous Tries', undef,
-				       {'only_body' => 1,
-					'bgcolor'   => '#FFFFFF',
-					'js_ready'  => 1,});
+				       {'only_body'      => 1,
+					'bgcolor'        => '#FFFFFF',
+					'js_ready'       => 1,
+				        'inherit_jsmath' => 1, });
     my $end_page =
 	&Apache::loncommon::end_page({'js_ready' => 1,});
     
