@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.268 2007/07/23 23:30:47 albertel Exp $
+# $Id: lonhomework.pm,v 1.268.2.1 2007/09/06 14:41:00 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -939,7 +939,7 @@ sub renderpage {
 	&Apache::lonxml::debug("Should be parsing now");
 	$result .= &Apache::lonxml::xmlparse($request, $target, $problem,
 					     &setup_vars($target),%mystyle);
-	undef($Apache::lonhomework::parsing_a_problem);
+	&finished_parsing();
 	if (!$output) { $result = ''; }
 	#$request->print("Result follows:");
 	if ($target eq 'modified') {
@@ -970,6 +970,11 @@ sub renderpage {
     }
 }
 
+sub finished_parsing {
+    undef($Apache::lonhomework::parsing_a_problem);
+    undef($Apache::lonhomework::parsing_a_task);
+}
+
 # with no arg it returns a HTML <option> list of the template titles
 # with one arg it returns the filename associated with the arg passed
 sub get_template_list {
