@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # random labelling tool
 #
-# $Id: randomlabel.pm,v 1.88 2007/05/23 22:36:21 albertel Exp $
+# $Id: randomlabel.pm,v 1.89 2007/06/20 17:33:33 banghart Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -147,12 +147,13 @@ sub start_randomlabel {
     } elsif ($target eq 'tex' && defined($bgimg)) {
 	$result.=&make_eps_image($bgimg,$parstack,$safeeval);
     } elsif ($target eq 'edit') {
+        my $only = join(',',&Apache::loncommon::filecategorytypes('Pictures'));
 	$result.=&Apache::edit::tag_start($target,$token);
 	$Apache::edit::bgimgsrc=
 	    &Apache::lonxml::get_param('bgimg',$parstack,$safeeval);
 	$Apache::edit::bgimgsrccurdepth=$Apache::lonxml::curdepth;
 	$result.=&Apache::edit::text_arg('Image:','bgimg',$token,75).' ';
-	$result.=&Apache::edit::browse('bgimg').' ';
+	$result.=&Apache::edit::browse('bgimg',undef,undef,$only).' ';
 	$result.=&Apache::edit::search('bgimg').'<br />'.
 	    &Apache::edit::text_arg('Width(pixel):' ,'width'   ,$token,6).
 	    &Apache::edit::text_arg('Height(pixel):','height'  ,$token,6).
