@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.390 2007/08/14 04:29:37 albertel Exp $
+# $Id: structuretags.pm,v 1.392 2007/08/31 19:31:16 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -157,6 +157,10 @@ function setSubmittedPart (part) {
 	$body_args{'no_title'}       = 1;
 	$body_args{'force_register'} = 1;
 	$body_args{'add_entries'}    = \%add_entries;	
+	if ($env{'environment.remote'} eq 'off'
+	    && $env{'request.state'} eq   'construct') {
+	    $body_args{'only_body'}  = 1;
+	}
     }
     $body_args{'no_auto_mt_title'} = 1;
     my $page_start = &Apache::loncommon::start_page($name,$extra_head,
@@ -207,7 +211,7 @@ sub get_resource_name {
 	$name = $Apache::lonhomework::name;
     } else {
 	my ($symb)=&Apache::lonnet::whichuser();
-	my $name=&Apache::lonnet::gettitle($symb);
+	$name=&Apache::lonnet::gettitle($symb);
 	if ($name eq '') {
 	    $name=&Apache::lonnet::EXT('resource.title');
 	    if ($name eq 'con_lost') { $name = ''; }
