@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # handler for DC-only modifiable course settings
 #
-# $Id: lonmodifycourse.pm,v 1.30 2007/01/15 01:08:53 raeburn Exp $
+# $Id: lonmodifycourse.pm,v 1.31 2007/03/08 01:58:45 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -859,7 +859,7 @@ sub handler {
         return OK;
     }
     my $dom = $env{'request.role.domain'};
-    my $domdesc = $Apache::lonnet::domaindescription{$dom}; 
+    my $domdesc = &Apache::lonnet::domain($dom,'description');
     if (&Apache::lonnet::allowed('ccc',$dom)) {
         &Apache::loncommon::content_type($r,'text/html');
         $r->send_http_header;
