@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Syllabus
 #
-# $Id: lonsyllabus.pm,v 1.59 2007/05/02 01:33:49 albertel Exp $
+# $Id: lonsyllabus.pm,v 1.62 2007/07/27 00:24:50 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -66,9 +66,6 @@ sub handler {
 
 # ------------------------------------------------------------ Print the screen
 
-    my $rss_link =
-	&Apache::lonrss::rss_link('http://'.$ENV{'HTTP_HOST'}.'/public/'.$cdom.'/'.$cnum.'/Course_Announcements.rss');
-
     if ($target eq 'tex') {
 	$r->print(&Apache::lonprintout::print_latex_header($env{'form.latex_type'}));
     } 
@@ -112,6 +109,7 @@ sub handler {
        
 # ----------------------------------------------------------------- Make header 
     if ($target ne 'tex') {
+	my $rss_link = &Apache::lonrss::rss_link($cnum,$cdom);
 	my $start_page = 
 	    &Apache::loncommon::start_page("Syllabus", $rss_link,
 					   {'function'       => $forcestudent,
@@ -137,13 +135,14 @@ sub handler {
 # -------------------------------------------------------- Get course personnel
     my %coursepersonnel=&Apache::lonnet::get_course_adv_roles($cdom.'/'.$cnum);
     if ($target ne 'tex') {
-	$r->print('<table border="2">');
+	$r->print(&Apache::loncommon::start_data_table());
     } else {
 	$r->print('\begin{tabular}{|p{0.45\textwidth}|p{0.45\textwidth}|}\hline');
     }
     foreach my $element (sort keys %coursepersonnel) {
 	if ($target ne 'tex') {
-	    $r->print('<tr><td>'.$element.'</td><td>');
+	    $r->print(&Apache::loncommon::start_data_table_row().
+		      '<td>'.$element.'</td><td>');
 	} else {
 	    $r->print(' '.&Apache::lonxml::xmlparse($r,'tex',$element).' & '); 
 	}
@@ -159,13 +158,13 @@ sub handler {
 	    }
 	}
 	if ($target ne 'tex') {
-	    $r->print('</td></tr>');
+	    $r->print('</td>'.&Apache::loncommon::end_data_table_row());
 	} else {
 	    $r->print('\\\\ \hline');
 	}
     }
     if ($target ne 'tex') {
-	$r->print('</table>');
+	$r->print(&Apache::loncommon::end_data_table());
     } else {
 	$r->print('\end{tabular}\\\\');
     }
@@ -261,12 +260,16 @@ sub handler {
                      $syllabus{'uploaded.domain'});
        if ($target ne 'tex') {
 	   $r->print('<table><tr><td>'.&mt('Last updated').':</td><td>'.
-		     $lastmod.'</td><td>'.&mt('by').' '.$who.
+		     $lastmod.'</td><td>'.
+		     ($who ? &mt('by').' '.$who
+                           : '' ).
 		     '</td></tr></table><p>');
        } else {
-	   $r->print('\\\\ '.&mt('Last updated').': '.$lastmod.' '.&mt('by').'\\\\ '.
-		     &Apache::loncommon::plainname($syllabus{'uploaded.name'},
-                     $syllabus{'uploaded.domain'}).'\\\\');
+	   $r->print('\\\\ '.&mt('Last updated').': '.$lastmod.' '.
+		     ($who? &mt('by').'\\\\ '.
+		            &Apache::loncommon::plainname($syllabus{'uploaded.name'},$syllabus{'uploaded.domain'})
+		          :'')
+		     .'\\\\');
        }
        if ($allowed) {
 	   $r->print('<form method="post">'.
