@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # portfolio browser
 #
-# $Id: portfolio.pm,v 1.184.2.1 2007/07/10 20:57:10 albertel Exp $
+# $Id: portfolio.pm,v 1.186 2007/07/10 20:51:46 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -289,8 +289,6 @@ sub display_directory {
 			  my ($bfile)=split('&',$b,2);
 			  return (lc($afile) cmp lc($bfile));
 		      } (@$dir_list)) {
-    	#$strip holds directory/file name
-    	#$dom 
     	my ($filename,$dom,undef,$testdir,undef,undef,undef,undef,$size,undef,$mtime,undef,undef,undef,$obs,undef)=split(/\&/,$dir_line,16); 
     	$filename =~ s/\s+$//;
     	my ($fname,$version,$extension) = &Apache::grades::file_name_version_ext($filename);
@@ -630,11 +628,8 @@ sub delete_dir_confirmed {
 		  ') while trying to delete '.$directory_name.'</span><br />');
     } else {
         # now remove from recent
-#        $r->print('<br /> removing '.$directory_name.'<br /');
         &Apache::lonhtmlcommon::remove_recent($namespace,[$directory_name.'/']);
         my @dirs = split m!/!, $directory_name;
-        
-#        $directory_name =~ m/^(\/*\/)(\/*.)$/;
         $directory_name='/';
         for (my $i=1; $i < (@dirs - 1); $i ++){
             $directory_name .= $dirs[$i].'/';
@@ -1740,11 +1735,11 @@ ENDSMP
         </script>
 ENDSMP
     $r->print($javascript);
-    $r->print("<h1>Select portfolio files</h1>
-                Check as many as you wish in response to the problem.<br />");
+    $r->print("<h1>".&mt('Select portfolio files')."</h1>".
+                &mt('Check as many as you wish in response to the problem.')."<br />");
     my @otherfiles=&Apache::lonnet::files_not_in_path($env{'user.name'}, $env{'form.currentpath'});
     if (@otherfiles) {
-	$r->print("<strong>Files selected from other directories:</strong><br />");
+	$r->print("<strong>".&mt('Files selected from other directories:')."</strong><br />");
 	foreach my $file (@otherfiles) {
 	    $r->print($file."<br />");
 	}
@@ -1778,17 +1773,23 @@ sub check_for_upload {
     my $current_disk_usage = &Apache::lonnet::diskusage($udom,$uname,$portfolio_root);
 
     if (($current_disk_usage + $filesize) > $disk_quota){
-        my $msg = '<span class="LC_error">Unable to upload <strong>'.$fname.' (size = '.$filesize.' kilobytes)</strong>. Disk quota will be exceeded.</span>'.
-	    '<br />Disk quota is '.$disk_quota.' kilobytes. Your current disk usage is '.$current_disk_usage.' kilobytes.';
+        my $msg = '<span class="LC_error">'.
+                &mt('Unable to upload [_1]. (size = [_2] kilobytes). Disk quota will be exceeded.','<span class="LC_filename">'.$fname.'</span>',$filesize).'</span>'.
+                  '<br />'.&mt('Disk quota is [_1] kilobytes. Your current disk usage is [_2] kilobytes.',$disk_quota,$current_disk_usage);
 	return ('will_exceed_quota',$msg);
     } elsif ($found_file) {
         if ($locked_file) {
-            my $msg = '<span class="LC_error">'.'Unable to upload <strong>'.$fname.'</strong>, a <strong>locked</strong> file by that name was found in <strong>'.$port_path.$path.'</strong></span>'.
-		'<br />You will be able to rename or delete existing '.$fname.' after a grade has been assigned.';
+            my $msg = '<span class="LC_error">';
+            $msg .= &mt('Unable to upload [_1] a locked file by that name was found in [_2].','<span class="LC_filename">'.$fname.'</span>','<span class="LC_filename">'.$port_path.$env{'form.currentpath'}.'</span>');
+            $msg .= '</span><br />';
+            $msg .= &mt('You will be able to rename or delete existing [_1] after a grade has been assigned.','<span class="LC_filename">'.$fname.'</span>');
 	    return ('file_locked',$msg);
 	} else {
-            my $msg = '<span class="LC_error">'.'Unable to upload <strong>'.$fname.'</strong>, a file by that name was found in <strong>'.$port_path.$path.'</strong></span>'.
-		'<br />To upload, rename or delete existing '.$fname.' in '.$port_path.$path;
+            my $msg = '<span class="LC_error">';
+            $msg .= &mt('Unable to upload [_1]. A file by that name was found in [_2].','<span class="LC_filename">'.$fname.'</span>',$port_path.$env{'form.currentpath'});
+            $msg .= '</span>';
+            $msg .= '<br />';
+            $msg .= &mt('To upload, rename or delete existing [_1] in [_2].','<span class="LC_filename">'.$fname.'</span>', $port_path.$env{'form.currentpath'});
 	    return ('file_exists',$msg);
 	}
     }
@@ -1929,7 +1930,7 @@ sub lock_info {
 	    }
         }
     }
-    $r->print(&done('Back',$url));
+    $r->print(&done(&mt('Back'),$url));
     return 'ok';
 }
 
@@ -1953,8 +1954,8 @@ sub createdir {
         }
     }
     if ($found_file){
-    	    $r->print('<span class="LC_error">'.'Unable to create a directory named <strong>'.$newdir.
-    	            ' </strong>a file or directory by that name already exists.</span><br />');
+    	    $r->print('<span class="LC_error">'.&mt('Unable to create a directory named').' <strong>'.$newdir.
+    	            ' </strong>'.&mt('a file or directory by that name already exists.').'</span><br />');
     } else {
         my ($uname,$udom) = &get_name_dom();
         my $port_path = &get_port_path();
@@ -1966,7 +1967,7 @@ sub createdir {
         }
     }
     if ($newdir ne $env{'form.newdir'}) {
-        $r->print("The new directory name was changed from:<br /><strong>".$env{'form.newdir'}."</strong> to <strong>$newdir </strong>");  
+        $r->print(&mt("The new directory name was changed from:<br /><strong>").$env{'form.newdir'}."</strong> ".&mt('to')." <strong>$newdir </strong>");  
     }
     $r->print(&done(undef,$url));
 }
@@ -2161,16 +2162,16 @@ sub handler {
                                       $env{'request.course.id'}.'/'.$group))) {
                     $portfolio_root = &get_portfolio_root();
                 } else {
-                    $r->print('You do not have the privileges required to access the shared files space for this group.');
+                    $r->print(&mt('You do not have the privileges required to access the shared files space for this group.'));
                     $earlyout = 1;
                 }
             } else {
-                $r->print('Not a valid group for this course');
+                $r->print(&mt('Not a valid group for this course'));
                 $earlyout = 1;
             }
             $title = &mt('Group files').' for '.$group; 
         } else {
-            $r->print('Invalid group');
+            $r->print(&mt('Invalid group'));
             $earlyout = 1;
         }
         if ($earlyout) { return OK; }
@@ -2226,16 +2227,14 @@ sub handler {
          return OK;
     }
 	if (($env{'form.storeupl'}) & (!$env{'form.uploaddoc.filename'})){
-   	    $r->print('<span class="LC_error">'.
-		      'No file was selected to upload.'.
-		      'To upload a file, click <strong>Browse...</strong>'.
-		      ', select a file, then click <strong>Upload</strong>.'.
-		      '</span>');
+   	    $r->print('<span class="LC_error">');
+   	    $r->print(&mt('No file was selected to upload. '));
+	    $r->print(&mt('To upload a file, click <strong>Browse...</strong> select a file, then click <strong>Upload</strong>.'));
+	    $r->print('</span>');
 	}
     if ($env{'form.meta'}) {
         &open_form($r,$url);
-#        $r->print(&edit_meta_data($r, $env{'form.currentpath'}.$env{'form.selectfile'}));
-        $r->print('Edit the meta data<br />');
+        $r->print(&mt('Edit the meta data').'<br />');
         &close_form($r,$url);
     }
     if ($env{'form.store'}) {
