@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.83 2007/04/26 21:17:16 albertel Exp $
+# $Id: loncfile.pm,v 1.86 2007/07/25 19:56:57 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -226,12 +226,16 @@ sub empty_directory {
 
 =over 4
 
-=item  $user   - string [in] - Name of the user for which to check.
+=item  $user     - string [in] - Name of the user for which to check.
 
-=item  $domain - string [in] - Name of the domain in which the resource
+=item  $domain   - string [in] - Name of the domain in which the resource
                           might have been published.
 
-=item  $file   - string [in] - Name of the file.
+=item  $file     - string [in] - Name of the file.
+
+=item  $creating - string [in] - optional, type of object being created,
+                               either 'directory' or 'file'. Defaults to
+                               'file' if unspecified.
 
 =back
 
@@ -251,7 +255,9 @@ Returns:
 =cut
 
 sub exists {
-    my ($user, $domain, $construct) = @_;
+    my ($user, $domain, $construct, $creating) = @_;
+    $creating ||= 'file';
+
     my $published=$construct;
     $published=~
 	s{^/home/$user/public_html/}{/home/httpd/html/res/$domain/$user/};
@@ -266,8 +272,15 @@ sub exists {
 	    $type = 'warning';
 	    $result.='<p><span class="LC_warning">'.&mt('Warning: target file exists, and has been published!').'</span></p>';
 	} else {
-	    $type = 'warning';
-	    $result.='<p><span class="LC_warning">'.&mt('Warning: a published file of this names exists.').'</span></p>';
+	    my $published_type = (-d $published) ? 'directory' : 'file';
+
+	    if ($published_type eq $creating) {
+		$type = 'warning';
+		$result.='<p><span class="LC_warning">'.&mt("Warning: a published $published_type of this name exists.").'</span></p>';
+	    } else {
+		$type = 'error';
+		$result.='<p><span class="LC_error">'.&mt("Error: a published $published_type of this name exists.").'</span></p>';
+	    }
 	}
     } elsif ( -e $construct) {
 	$type = 'warning';
@@ -340,6 +353,12 @@ sub cleanDest {
 	    $dest=~s|.*/||;
 	}
     }
+    if ($dest =~ /\.(\d+)\.(\w+)$/){
+	$request->print('<span class="LC_error">'
+			.&mt('Bad filename [_1].<br /> <tt>(name).(number).(extension)</tt> not allowed. <br /> Removing the <tt>.number.</tt> from requested filename.',$dest)
+			.'</span>');
+	$dest =~ s/\.(\d+)(\.\w+)$/$2/;
+    }
     if ($foundbad) {
 	$request->print("<p><span class=\"LC_error\">".&mt('Invalid characters in requested name have been removed.')."</span></p>");
     }
@@ -674,9 +693,9 @@ causes the newdir operation to transition into phase 2.  The hidden field
 sub NewDir1 {
     my ($request, $username, $domain, $fn, $newfilename, $mode) = @_;
 
-    my ($type, $result)=&exists($username,$domain,$newfilename);
+    my ($type, $result)=&exists($username,$domain,$newfilename,'directory');
     $request->print($result);
-    if ($result) {
+    if ($type eq 'error') {
 	$request->print('</form>');
     } else {
 	if ($mode eq 'testbank') {
@@ -852,6 +871,7 @@ sub phaseone {
 	      $env{'form.action'} eq 'newsequencefile' ||
 	      $env{'form.action'} eq 'newrightsfile' ||
 	      $env{'form.action'} eq 'newstyfile' ||
+	      $env{'form.action'} eq 'newtaskfile' ||
               $env{'form.action'} eq 'newlibraryfile' ||
 	      $env{'form.action'} eq 'Select Action') {
         my $empty=&mt('Type Name Here');
@@ -1351,6 +1371,7 @@ function writeDone() {
 	     $env{'form.action'} eq 'newsequencefile' ||
 	     $env{'form.action'} eq 'newrightsfile' ||
 	     $env{'form.action'} eq 'newstyfile' ||
+	     $env{'form.action'} eq 'newtaskfile' ||
              $env{'form.action'} eq 'newlibraryfile' ||
 	     $env{'form.action'} eq 'Select Action' ) {
 	$r->print('<h3>'.&mt('New Resource').'</h3>');
